<!-- insertion marker -->

## [0.1.0](https://github.com/MarTrepodi/mhanndalorian-bot-api/releases/tag/0.1.0) - 2025-02-23

<small>[Compare with first commit](https://github.com/MarTrepodi/mhanndalorian-bot-api/compare/d8ca0c85027fde044efebcfd42923012183ec2d1...0.1.0)</small>

### Features

- add x-discord-id header for Registry
  endpoints ([febde24](https://github.com/MarTrepodi/mhanndalorian-bot-api/commit/febde24cc746e5ba8373610182aa54aa0d8aa175)
  by MarTrepodi).


## [v0.1.2](https://github.com/MarTrepodi/mhanndalorian-bot-api/releases/tag/0.0.1) - 2025-02-08

<small>[Compare with first commit](https://github.com/MarTrepodi/mhanndalorian-bot-api/compare/d8ca0c85027fde044efebcfd42923012183ec2d1...0.0.1)</small>
